@@ -16,9 +16,7 @@ class Collection(Behance):
         _url = "%s?api_key=%s" % (_url, self.auth_key)
 
         _results = self._get_api_data(_url)['collection']
-
-        for k, v in _results.items():
-            self._add_property(k, v)
+        self.set_data(_results)
 
     def get_projects(self, **kwargs):
         _base_url = url_join(self.base_url, self.collection_id, 'projects')
@@ -28,4 +26,4 @@ class Collection(Behance):
         else:
             _url = '%s?api_key=%s' % (_base_url, self.auth_key)
 
-        return self._get_api_data(_url)['projects']
+        return self._parse_data(self._get_api_data(_url)['projects'])
